@@ -2,7 +2,7 @@ package RedisDB;
 
 use strict;
 use warnings;
-our $VERSION = "2.41";
+our $VERSION = "2.42";
 $VERSION = eval $VERSION;
 
 use RedisDB::Error;
@@ -953,6 +953,14 @@ sub _parse_client_list {
     return $res;
 }
 
+=head2 $self->cluster_info([\&callback])
+
+return information and statistics about the cluster. Redis-server returns
+information in form of I<field:value>, the I<cluster_info> method parses result
+and returns it as a hash reference.
+
+=cut
+
 sub cluster_info {
     my $self = shift;
     my $orig = $_[-1];
@@ -969,6 +977,14 @@ sub cluster_info {
     }
 }
 
+=head2 $self->cluster_nodes
+
+return list of cluster nodes. Each node represented as a hash with the
+following keys: node_id, address, host, port, flags, master_id, last_ping_sent,
+last_pong_received, link_state, slots.
+
+=cut
+
 sub cluster_nodes {
     my $self = shift;
 
@@ -1002,6 +1018,68 @@ sub cluster_nodes {
     return \@nodes;
 }
 
+sub _parse_role {
+    my $role = shift;
+
+    my $parsed = {
+        role => $role->[0],
+    };
+    if ( $parsed->{role} eq 'master' ) {
+        $parsed->{replication_offset} = $role->[1];
+        for ( @{ $role->[2] } ) {
+            push @{ $parsed->{slaves} },
+              {
+                host               => $_->[0],
+                port               => $_->[1],
+                replication_offset => $_->[2],
+              };
+        }
+    }
+    elsif ( $parsed->{role} eq 'slave' ) {
+        $parsed->{master} = {
+            host => $role->[1],
+            port => $role->[2],
+        };
+        $parsed->{status}             = $role->[3];
+        $parsed->{replication_offset} = $role->[4];
+    }
+    elsif ( $parsed->{role} eq 'sentinel' ) {
+        for ( @{ $role->[1] } ) {
+            push @{ $parsed->{services} }, $_;
+        }
+    } else {
+        confess "Unknown role $parsed->{role}";
+    }
+
+    return $parsed;
+}
+
+=head2 $self->role([\&callback])
+
+return reference to a hash describing the role of the server. Hash contains
+"role" element that can be either "master", "slave", or "sentinel". For master
+hash will also contain "replication_offset" and "slaves" elements, for slave it
+will contain "master", "status", and "replication_offset" elements, and for
+sentinel it will contain "services".
+
+=cut
+
+sub role {
+    my $self = shift;
+    my $orig = $_[-1];
+    if ( $orig && ref $orig eq 'CODE' ) {
+        my $cb = sub {
+            my ( $redis, $role ) = @_;
+            $orig->( $redis, _parse_role($role) );
+        };
+        return $self->send_command( 'ROLE', $cb );
+    }
+    else {
+        my $role = $self->execute('ROLE');
+        return _parse_role($role);
+    }
+}
+
 =head2 $self->shutdown
 
 Shuts the redis server down. Returns undef, as the server doesn't send the
@@ -1611,6 +1689,16 @@ sub discard {
     return $res;
 }
 
+=head1 CLUSTER SUPPORT
+
+For accessing redis cluster use L<RedisDB::Cluster> package
+
+=head1 SENTINEL SUPPORT
+
+For accessing redis servers managed by sentinel use L<RedisDB::Sentinel> package
+
+=cut
+
 1;
 
 __END__
