@@ -2,7 +2,7 @@ package RedisDB::Cluster;
 
 use strict;
 use warnings;
-our $VERSION = "2.41";
+our $VERSION = "2.42";
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -141,8 +141,6 @@ RedisDB::Cluster - client for redis cluster
 
 This module allows you to access redis cluster.
 
-B<WARNING:> this module is at early stage of development
-
 =head1 METHODS
 
 =cut
@@ -225,8 +223,8 @@ include key as an argument is not supported. If I<@args> contains several keys,
 all of them should belong to the same slot, otherwise redis-server will return
 an error if some of the keys are stored on a different node.
 
-Module also defines wrapper methods with names matching to redis commands, so
-you can use
+Module also defines wrapper methods with names matching corresponding redis
+commands, so you can use
 
     $cluster->set( "foo", "bar" );
     $cluster->inc("baz");
@@ -485,8 +483,10 @@ sub remove_node {
             push @masters, $_;
         }
         my @slots;
+        my %slots_at;
         for my $i ( 0 .. 16383 ) {
             push @slots, $i if $self->{_slots}[$i] eq $node_key;
+            $slots_at{ $self->{_slots}[$i] }++;
         }
         if ($DEBUG) {
             warn "Node to remove is a master with "
@@ -498,10 +498,11 @@ sub remove_node {
               . scalar(@masters)
               . " other masters in cluster\n";
         }
-        my $slots_per_master  = int( @slots / @masters + 1 );
+        my $slots_per_master  = int( 16384 / @masters + 1 );
         my $slaves_per_master = int( @slaves / @masters + 1 );
         for my $master (@masters) {
-            for ( 1 .. $slots_per_master ) {
+            my $key = "$master->{host}:$master->{port}";
+            for ( $slots_at{$key} + 1 .. $slots_per_master ) {
                 my $slot = shift @slots;
                 last unless defined $slot;
                 $self->migrate_slot( $slot, $master );
